type OnRecordRowData = {
    row: number;
    data: {
        [columnName: string]: {
            value: string | number | null;
            isValid: boolean;
        };
    };
};
type OnRecordRowResponse = {
    row: number;
    data: {
        [columnName: string]: Array<{
            message: string;
            level: "error" | "info" | "healing";
        }>;
    };
};
export type onDataResponseWithoutBatching = Promise<{
    errors?: {
        row: Record<string, string | number | undefined>;
        error: string;
    }[];
    successes?: Record<string, string | number | undefined>[];
} | void>;
export type onDataResponseWithBatching = Promise<{
    errors?: {
        row: number;
        error: string;
    }[];
    successes?: Record<string, string | number | undefined>[];
} | void>;
export type onRecordsInitialType = ({ uploadId, fileName, importerId, batch, user, metadata, rows, }: {
    uploadId: string;
    fileName: string;
    importerId: string;
    batch: {
        index: number;
        count: number;
        totalRows: number;
    };
    user?: Record<string, string | number> | null;
    metadata?: Record<string, string | number> | null;
    rows: OnRecordRowData[];
}) => Promise<OnRecordRowResponse[] | void> | OnRecordRowResponse[] | void;
export type onRecordEditType = ({ uploadId, fileName, importerId, user, metadata, row, }: {
    uploadId: string;
    fileName: string;
    importerId: string;
    user?: Record<string, string | number> | null;
    metadata?: Record<string, string | number> | null;
    row: OnRecordRowData;
}) => Promise<OnRecordRowResponse | OnRecordRowResponse[] | void> | OnRecordRowResponse | OnRecordRowResponse[] | void;
export type CsvData = {
    uploadId: number;
    fileName: string;
    rows: Record<string, string | number>[];
    user?: Record<string, string | number>;
    metadata?: Record<string, string | number>;
    matchedColumnsMap?: Record<string, string | number>;
    uploadedFileHeaders?: Array<string>;
    importedRowsCount: number;
    batch?: {
        index: number;
        count: number;
        totalRows: number;
    };
};
type HeaderTextTransformType = "capitalize" | "lowercase" | "uppercase" | "none";
export type ThemeType = {
    global: {
        backgroundColor: string;
        primaryTextColor: string;
        secondaryTextColor: string;
        successColor: string;
        warningColor: string;
        outerPadding?: "true" | "false" | undefined | null;
    };
    buttons: {
        primary: {
            backgroundColor: string;
            color: string;
            border: string;
            borderRadius: string;
            boxShadow: string;
            ":hover": {
                backgroundColor: string;
                color: string;
            };
            fontSize?: string;
            fontWeight?: string;
            fontStyle?: string;
        };
        secondary: {
            backgroundColor: string;
            color: string;
            border: string;
            borderRadius: string;
            boxShadow: string;
            ":hover": {
                backgroundColor: string;
                color: string;
            };
            fontSize?: string;
            fontWeight?: string;
            fontStyle?: string;
        };
        tertiary?: {
            backgroundColor: string;
            color: string;
            border: string;
            borderRadius: string;
            boxShadow: string;
            ":hover": {
                backgroundColor: string;
                color: string;
            };
            fontSize?: string;
            fontWeight?: string;
            fontStyle?: string;
        } | undefined | null;
    };
    cells?: {
        error?: {
            color: string;
            backgroundColor: string;
        };
        info?: {
            color: string;
            backgroundColor: string;
        };
        healing?: {
            color: string;
            backgroundColor: string;
        };
    } | null | undefined;
    tables?: {
        headerColor: string;
        headerBackgroundColor: string;
        borderColor: string;
        color: string;
        headerTextTransform?: HeaderTextTransformType | undefined | null;
    } | null | undefined;
    steps?: {
        backgroundColor: string;
        activeBackgroundColor: string;
        completedBackgroundColor: string;
        color: string;
        activeColor: string;
        completedColor: string;
        borderColor: string;
        activeBorderColor: string;
        completedBorderColor: string;
        connectorColor: string;
        titleColor: string;
    } | null | undefined;
    modals?: {
        backgroundColor: string;
        color: string;
        border: string;
        boxShadow: string;
        buttons: {
            confirm: {
                backgroundColor: string;
                color: string;
                border: string;
                borderRadius: string;
                boxShadow: string;
                ":hover": {
                    backgroundColor: string;
                    color: string;
                };
                fontSize?: string;
                fontWeight?: string;
                fontStyle?: string;
            };
            cancel: {
                backgroundColor: string;
                color: string;
                border: string;
                borderRadius: string;
                boxShadow: string;
                ":hover": {
                    backgroundColor: string;
                    color: string;
                };
                fontSize?: string;
                fontWeight?: string;
                fontStyle?: string;
            };
        };
    } | null | undefined;
    customFont?: Array<{
        fontFamily: string;
        fontStyle: string | undefined;
        fontWeight: string | undefined;
        fontDisplay: string | undefined;
        srcURL: string;
        srcFormat: string;
        unicodeRange: string | undefined;
    }> | undefined | null;
};
type DateFormatsType = "DD/MM/YYYY" | "DD/MM/YY" | "DD-MM-YYYY" | "DD-MM-YY" | "DD.MM.YYYY" | "DD.MM.YY" | "MM/DD/YYYY" | "MM/DD/YY" | "MM-DD-YYYY" | "MM-DD-YY" | "MM.DD.YYYY" | "MM.DD.YY" | "YYYY-MM-DD" | "DATEVALUE";
type BooleanFormatsType = "true,false" | "yes,no" | "1,0";
export type DynamicColumnsType = Array<{
    name: string;
    displayName?: string | null | undefined;
    description?: string | null | undefined;
    example?: string | null | undefined;
    mustBeMatched?: boolean | null | undefined;
    valueCannotBeBlank?: boolean | null | undefined;
    validationHook?: boolean | null | undefined;
    validationFormat: {
        type: "string";
    } | {
        type: "number";
    } | {
        type: "date";
        format: DateFormatsType;
    } | {
        type: "phone";
    } | {
        type: "email";
        format?: "allowDisplayName" | null | undefined;
    } | {
        type: "regex";
        format: string;
    } | {
        type: "select";
        format: string;
    } | {
        type: "boolean";
        format: BooleanFormatsType;
    };
    customValidationErrorMessage?: string | null | undefined;
}>;
export type Language = "en" | "fr" | "es" | "pt" | "de" | "nl" | "it" | "ar";
export type columnWidthType = "auto" | "fixed";
export type onErrorType = ({ importerId, uploadId, user, metadata, error, }: {
    importerId: string;
    uploadId?: string;
    user?: Record<string, string | number> | null;
    metadata?: Record<string, string | number> | null;
    error: string;
}) => void;
export type onMatchColumnsType = ({ configuredColumns, uploadedFileHeaders, headerRow, }: {
    configuredColumns: string[];
    uploadedFileHeaders: string[];
    headerRow: boolean;
}) => Promise<Record<string, string | undefined>> | Record<string, string | undefined> | undefined | void;
export type customTextType = {
    importedRows: {
        text: string | undefined;
        downloadRowsButton: string | undefined;
    } | undefined;
    rejectedRows: {
        text: string | undefined;
        downloadRowsButton: string | undefined;
    } | undefined;
};
export type fileFormats = "xls" | "xlsx" | "xlsb" | "csv";
export type onFileUploadType = (({ file }: {
    file: File;
}) => void) | undefined;
export {};
//# sourceMappingURL=types.d.ts.map